@@ -27,12 +27,12 @@ double * readeph_dummy(int mp, const char *name, double jd_tdb, int *error) {
   double *pv;
 
   if(!name || !error) {
-    set_error(-1, EINVAL, fn, "NULL parameter: name=%p, error=%p", name, error);
+    novas_set_errno(EINVAL, fn, "NULL parameter: name=%p, error=%p", name, error);
     return NULL;
   }
 
   if(isnanf(jd_tdb)) {
-    set_error(-1, EINVAL, fn, "NaN jd_tdb");
+    novas_set_errno(-1, EINVAL, fn, "NaN jd_tdb");
     *error = -1;
     return NULL;
   }
